function OUT = Hydrocyclone( IN )


% Parametros
Ni	= 10;
Rm	= 2.75;	% ton/m^3
Rw	= 1;		% ton/m^3
x	= [ 1000 710 500 355 250 180 125 90 63 45 38 ]';	% micras

% Entradas
WF		= IN(1);
MF		= IN(2);
mFi	= IN(3:Ni+2);

Du		= IN(Ni+3);
Di		= IN(Ni+4);
Do		= IN(Ni+5);
Alpha	= IN(Ni+6);
K		= IN(Ni+7:Ni+15);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

QF			= (1000/60)*(MF / Rm + WF / Rw); %[Lt/min]

Cw			= 100*MF /( MF + WF );

x50		= 10^( K(1) * Do - K(2) * Du + K(3) * Di + K(4) * Cw - K(5) * QF + K(6) );	% micras

Rf			= K(7) * Du / WF - K(8) / WF + K(9);


Rf=Rf/1.6;

if Rf>1;Rf=0.8;end
if Rf<0;Rf=0.1;end



Euc		= ( exp( Alpha * x / x50 ) - 1 ) ./ ( exp( Alpha * x / x50 ) + exp( Alpha ) - 2 );

Eua		= Euc(1:Ni) * ( 1 - Rf ) + Rf;

WDU		= WF * Rf;

WDO		= WF - WDU;

MDU_mDUi	= Eua .* ( MF * mFi );

MDO_mDOi	= MF * mFi - MDU_mDUi;

MDU		= sum( MDU_mDUi );

MDO		= MF - MDU;

mDUi		= MDU_mDUi / MDU;

mDOi		= MDO_mDOi / MDO;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Salidas
OUT(1)				= WDO;
OUT(2)				= MDO;
OUT(3:Ni+2)			= mDOi;

OUT(Ni+3)			= x50;

OUT(Ni+4)			= WDU;
OUT(Ni+5)			= MDU;
OUT(Ni+6:2*Ni+5)	= mDUi;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
