function OUT = BallMill_Power( IN )

% Parametros
E	= 0.4;
g	= 9.814;	% m/s^2
k	= 1.26;
Rb	= 7.8;	% ton/m^3
Rm	= 2.75;	% ton/m^3
Rw	= 1;		% ton/m^3
U	= 1;

% Entradas
D		= IN(1);	% 8 (m)
Dt		= IN(2);	% 2 (m)
Jt		= IN(3);	% 0.35
L		= IN(4);	% 4 (m)
Lc		= IN(5);	% 6 (m)
PhiP	= IN(6);	% 0.72
RPM	= IN(7);	% 10.77 (rpm)

WD		= IN(8);
MD		= IN(9);

QD		= IN(10);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%QD	= MD / Rm + WD / Rw;

if QD==0; QD=50; end

Rp	= ( MD + WD ) / QD;

S	= ( MD / Rm ) / QD;

Jb	= Jt;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Step 1
Rc	= ( Jt * Rm * ( 1 - E + E * U * S ) + Jb * ( Rb - Rm ) * ( 1 - E ) + Jt * E * U * ( 1 - S ) ) / Jt;

% Step 2
if PhiP > 0.35 * ( 3.364 - Jt )
   Phi_C	= PhiP;
else
   Phi_C	= 0.35 * ( 3.364 - Jt );
end

Theta_T	= 2.5307 * ( 1.2796 - Jt ) * ( 1 - exp( -19.42 * ( Phi_C - PhiP ) ) ) + pi / 2;

Theta_TO	= 3.395;

Theta_S	= pi / 2 - ( Theta_T - pi / 2 ) * ( ( 0.3386 + 0.1041 * PhiP ) + ( 1.54 - 2.5673 * PhiP ) * Jt );

% Step 3
rm		= D / 2;

Nm		= RPM / 60;

NN		= Nm / 2;

tc		= ( 2 * pi - Theta_T + Theta_S ) / ( 2 * pi * NN );

rr		= rm / 2 * ( 1 + ( 1 - ( 2 * pi * Jt ) / ( 2 * pi + Theta_S - Theta_T ) )^0.5 );

tf		= ( 2 * rr * ( sin( Theta_S ) - sin( Theta_T ) ) / g )^0.5;

Beta	= tc / ( tf + tc );

ri		= rm * ( 1 - ( 2 * pi * Beta * Jt ) / ( 2 * pi + Theta_S - Theta_T ) )^0.5;

% Step 4
z	= ( 1 - Jt )^0.4532;

% Step 5
Pnet	= ( pi * g * L * Nm * rm ) / ( 3 * ( rm - z * ri ) ) * ( 2 * rm^3 - 3 * z * rm^2 * ri ...
   + ri^3 * ( 3 * z - 2 ) ) ...
   * ( Rc * ( sin( Theta_S ) - sin( Theta_T ) ) + Rp * ( sin( Theta_T ) - sin( Theta_TO ) ) ) ...
   + L * Rc * ( Nm * rm * pi / ( rm - z * ri ) )^3 * ( ( rm - z * ri )^4 - ri^4 * ( z - 1 )^4 );

% Step 6
rt	= Dt / 2;

Ld	= ( Lc - L ) / 2;

Pc	= ( pi * Ld * g * Nm ) / ( 3 * ( rm - rt ) ) * ( rm^4 - 4 * rm * ri^3 + 3 * ri^4 ) ...
   * ( Rc * ( sin( Theta_S ) - sin( Theta_T ) ) + Rp * ( sin( Theta_T ) - sin( Theta_TO ) ) ) ...
   + ( 2 * pi^3 * Nm^3 * Ld * Rc ) / ( 5 * ( rm - rt ) ) * ( rm^5 - 5 * rm * ri^4 + 4 * ri^5 );

% Step 7
Pnl	= 1.68 * ( D^2.5 * PhiP * ( 0.667 * Ld + L ) )^0.82;

% Step 8
P	= Pnl + k * ( Pnet + Pc );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Salidas
OUT	= P;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
